local name, addon = ...
local parentName = addon['parentName'] or "BrokerPack"
local childName = "ArchWizard"
local defaults = {}
local options = {}
local db
local raceCurrencies = {}
local findings = {
	[12] = {	-- Kalimdor mapID 12
		[0] = true,
		[52843] = true, -- dwarf
		[63127] = true, -- nelf
		[63128] = true, -- troll
		[64397] = true, -- tol'vir
	},
	[13] = {	-- eastern kingdom mapID 13
		[0] = true,
		[64396] = true, -- nerubian
		[52843] = true, -- dwarf
		[63127] = true, -- nelf
		[63128] = true, -- troll
	},
	[101] = {	-- outland
		[64392] = true, -- orc
		[64394] = true, -- draenei
	},
	[113] = {	-- northrend
		[64396] = true, -- nerubian
		[63127] = true, -- nelf
		[63128] = true, -- troll
		[64395] = true, -- vrykul
	},
	[948] = {	-- maelstrom --948
	}, 
	[424] = {	-- pandaria
		[79868] = true, -- panda
		[79869] = true, -- mogu
		[95508] = true, -- mantis
	},
	[572] = { -- wod
		[109585] = true, -- arakkoa
		[109584] = true, -- oger
		[108439] = true, -- clans
	},
	[619] = { -- legion
		[130903] = true, -- Highborne
		[130904] = true, -- Highmountain Tauren
		[130905] = true, -- Demonic
	},
	[875] = { -- Zandalar
		[154989] = true, -- zandalar
	},
	[876] = { -- Kul Tiras
		[154990] = true, -- drust
	},
}
local function getContinent()
	local mapID = C_Map.GetBestMapForUnit("player")
	if(mapID) then
		local info = C_Map.GetMapInfo(mapID)
		if(info) then
			while(info and info['mapType'] and info['mapType'] > 2) do
				local newinfo = C_Map.GetMapInfo(info['parentMapID'])
				if(newinfo) then
					info = newinfo
				else
					break
				end
			end
			if(info['mapType'] == 2) then
				return info['mapID']
			end
		end
	end
end
local function fragmentUpdate()
	if(not IsAddOnLoaded("Blizzard_ArchaeologyUI")) then
		UIParentLoadAddOn("Blizzard_ArchaeologyUI")
	end
	local continent = getContinent()
	if(continent) then
		for i=1,GetNumArchaeologyRaces() do
			local raceName, raceTexture, raceItemID, raceCurrency, numFragmentsRequired = GetArchaeologyRaceInfo(i)
			if(raceName) then
				SetSelectedArtifact(i)
				local artifactName, artifactDescription, artifactRarity, artifactIcon, hoverDescription, keystoneCount, bgTexture, firstCompletionTime, completionCount = GetActiveArtifactByRace(i)
				if(type(raceCurrency) == 'number') then
						raceCurrencies[raceName] = {
							['cur'] = raceName,
							['tex'] = bgTexture,
							['id'] = raceItemID,
							['count'] = raceCurrency,
							['required'] = numFragmentsRequired,
							['quality'] = artifactRarity,
							['keystones'] = keystoneCount,
							['show'] = findings[continent] and findings[continent][raceItemID] or nil,
						}
				end
			end
		end
	end
end

local function OnTooltipShow(GameTooltip)
	fragmentUpdate()
	GameTooltip:AddLine(childName)
	GameTooltip:AddLine("")
	for k,v in pairs(raceCurrencies) do
		if((v['show'] or IsShiftKeyDown()) and v['required'] > 0) then
		GameTooltip:AddDoubleLine(addon:colorize(format("%s (%s/%s)",k,GetItemCount(v['id']),v['keystones'] or 0),v['quality']==1 and "6677ff" or "ffffff"),addon:colorize(format("%s/%s",v['count'],v['required']),v['count'] >= v['required'] and "00ff00" or ("ffffff")))
		end
	end
	GameTooltip:AddLine(addon:colorize("Press SHIFT for more info","00ff00"))
end

local function OnClick(self, button)
	if(button) then
		if(not IsAddOnLoaded("Blizzard_ArchaeologyUI")) then
			UIParentLoadAddOn("Blizzard_ArchaeologyUI")
		end
		if(ArchaeologyFrame:IsVisible()) then
			ArchaeologyFrame_Hide()
		else
			ArchaeologyFrame_Show()
		end
	end
end

local function OnText(message)
	addon:OnText(message, childName)
end

local function getPref(pref)
	return db[pref[#pref]]
end

local function setPref(pref,value)
	db[pref[#pref]] = value
end

local function init()
	options = addon:InitConfig(childName, true, {
		['name'] = childName,
		['type'] = "launcher",
		['OnTooltipShow'] = OnTooltipShow,
		['OnClick'] = OnClick,
	}, getPref, setPref)
	db = addon['db']['profile'][childName]
end

addon:startup(name, childName, init, true, defaults)
